@@ -109,6 +109,6 @@ def load_backend(bknd=None):
     if failed == list(Backends):
         raise ModuleNotFoundError(
             "Pyflocker needs atleast one backend among "
-            ", ".join(each.name.capitalize() for each in failed)
+            + ", ".join(each.name.capitalize() for each in failed)
             + " but none were found",  # noqa: W503
         )
