@@ -85,7 +85,7 @@ def locker(
     try:
         with open(file, "rb") as infile, open(newfile, "xb") as outfile:
             lockerf(infile, outfile, password, locking, **kwargs)
-    except exc.DecryptionError:
+    except (TypeError, exc.DecryptionError):
         # remove invalid file
         os.remove(newfile)
         raise
@@ -209,7 +209,7 @@ def lockerf(
     if metadata is None:
         metadata = b"CREATED BY: PYFLOCKER"
     else:
-        if len(metadata) < 32:
+        if len(metadata) > 32:
             raise ValueError("maximum metadata length exceeded")
 
     # header extract if decrypting,
